import LatexJS from "../lib/Latex.js";
import {onFirstVisible} from "../Util.js";

export class SkribblWord extends HTMLElement {
	constructor(word="",description=""){
		super();
		this.attachShadow({mode:"open"});
		this.shadowRoot.innerHTML = `
			<style>
				:host {
					display: block;
				}
				#description {
					padding-left: 20px;
					padding-right: 20px;
				}
			</style>
			<h3></h3>
			<div id="description"></div>
		`;
		this._word = this.shadowRoot.querySelector("h3");
		/** @type {LatexJS} */
		this._latexElement = null;
		this._description = "";
		this.word = word;
		this.description = description;
		onFirstVisible(this,()=>{
			this._latexElement = new LatexJS();
			this._latexElement.latex = this._description;
			this.shadowRoot.getElementById("description").appendChild(this._latexElement);
		});
	}

	set word(word){
		this.setAttribute("word",word);
	}

	get word(){
		return this.getAttribute("word");
	}

	set description(description){
		this.setAttribute("description",description);
	}

	get description(){
		return this.getAttribute("description");
	}

	attributeChangedCallback(name,oldValue,newValue){
		if (name=="word"){
			this._word.textContent = newValue;
		}else if(name=="description"){
			this._description = newValue;
			if (this._latexElement){
				this._latexElement.innerText = newValue;
			}
		}
	}

	static get observedAttributes(){
		return ["word","description"];
	}
}
export class SkribblTopic extends HTMLElement {
	constructor(name=""){
		super();
		this.attachShadow({mode:"open"});
		this.shadowRoot.innerHTML = `
			<style>
				:host {
					display: block;
					margin-bottom: 50px;
				}
				h2 {
					text-align: center;
				}
			</style>
			<h2></h2>
			<slot></slot>
		`;
		this._name = this.shadowRoot.querySelector("h2");
		this.name = name;
	}

	set name(name){
		this.setAttribute("name",name);
	}

	get name(){
		return this.getAttribute("name");
	}

	attributeChangedCallback(name,oldValue,newValue){
		if (name=="name"){
			this._name.textContent = newValue;
		}
	}

	static get observedAttributes(){
		return ["name"];
	}
}
customElements.define("skribbl-word",SkribblWord);
customElements.define("skribbl-topic",SkribblTopic);